@@ -7,7 +7,7 @@
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 package Nile::HTTP::Request;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 =pod
 
@@ -55,6 +55,7 @@ extends 'CGI::Simple';
 #Methods: HEAD, POST, GET, PUT, DELETE, PATCH
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 sub is_ajax {
+	my $self = shift;
 	if (exists $ENV{HTTP_X_REQUESTED_WITH} && lc($ENV{HTTP_X_REQUESTED_WITH}) eq 'xmlhttprequest') {
 		return 1;
 	}
@@ -72,8 +73,8 @@ sub base_url {
 	my $self = shift;
 	my $url =  $self->url();
 	my $script =  $self->url(-relative=>1);
-	$url =~ s/$script//;
-	$url = "$url/" if $url !~ m|/$|;
+	$url =~ s/\Q$script\E//;
+	$url = "$url/" if $url !~ m{/$};
 	return $url;
 }
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -81,7 +82,7 @@ sub abs_url {
 	my $self = shift;
 	my $url =  $self->url(-absolute=>1);
 	my $script =  $self->url(-relative=>1);
-	$url =~ s/$script//;
+	$url =~ s/\Q$script\E//;
 	$url = "$url/" if $url !~ m|/$|;
 	return $url;
 }
